import { CdnDeployInputs, CdnDeployOutputs } from './interface';
import { Client } from 'tencentcloud-sdk-nodejs/tencentcloud/services/cdn/v20180606/cdn_client';
import { Capi } from '@tencent-sdk/capi';
import { ApiCredentials } from '@tencent-serverless-framework/common';
export { CdnDeployInputs, CdnDeployOutputs } from './interface';
/** 腾讯云内容分发网络 (Cdn)for Serverless */
export declare class Cdn {
    credentials: ApiCredentials;
    client: Client;
    capi: Capi;
    /**
     * 构造函数
     *
     * @param credentials 认证信息
     */
    constructor(credentials?: ApiCredentials);
    /**
     * purgeCdnCache 用于批量提交目录刷新，根据域名的加速区域进行对应区域的刷新。
     * 内部调用 PurgePathCache 接口
     *
     * @param urls 要刷新的路径
     * @param flushType 刷新方式：flush：刷新产生更新的资源 delete：刷新全部资源
     */
    purgeCdnUrls(urls: string[], flushType?: string): Promise<void>;
    /**
     * pushCdnUrls 用于将指定 URL 资源列表加载至 CDN 节点，支持指定加速区域预热。
     * 内部调用 PushUrlsCache 接口
     *
     * @param urls URL 列表，需要包含协议头部 http:// 或 https://
     * @param userAgent 指定预热请求回源时 HTTP 请求的 User-Agent 头部，默认为 flush
     * @param area 预热生效区域 mainland：预热至境内节点 overseas：预热至境外节点 global：预热全球节点 不填充情况下，默认为 mainland， URL 中域名必须在对应区域启用了加速服务才能提交对应区域的预热任务
     */
    pushCdnUrls(urls: string[], userAgent?: string, area?: string): Promise<void>;
    /**
     * 根据域名查询 CDN 信息
     * 内部调用 DescribeDomains
     *
     * @param domain 域名
     * @returns 第一个找到的 CDN 信息
     */
    getCdnByDomain(domain: string): Promise<import("tencentcloud-sdk-nodejs/tencentcloud/services/cdn/v20180606/cdn_models").BriefDomain | undefined>;
    /**
     * 下线指定域名的 CDN 服务
     *
     * @param domain 域名
     */
    offlineCdnDomain(domain: string): Promise<void>;
    /**
     * 启用用户的 CDN 服务
     * (相当于在控制台点击开启 CDN 服务)
     */
    openCdnService(): Promise<void>;
    /**
     * 部署 CDN
     *
     * @param inputs 部署 CDN 时的输入
     * @returns 返回部署 CDN 后的输出
     */
    deploy(inputs: CdnDeployInputs): Promise<CdnDeployOutputs>;
    /**
     * 创建或更新 CDN
     *
     * @param inputs 输入
     * @returns 结果
     */
    createOrUpdateCdn(inputs: CdnDeployInputs): Promise<CdnDeployOutputs>;
    /**
     * 删除指定域名的 CDN
     *
     * @param inputs 输入信息
     * @param inputs.domain 输入中的域名
     * @returns 成功后返回空 object
     */
    remove(inputs: {
        /** 域名 */
        domain: string;
    }): Promise<{}>;
}
