import { CamelCasedProps } from '@tencent-serverless-framework/common';
import { AddCdnDomainRequest, Origin, ServerCert } from 'tencentcloud-sdk-nodejs/tencentcloud/services/cdn/v20180606/cdn_models';
/** 源输入 */
export interface OriginInputs extends CamelCasedProps<Origin> {
}
/** 证书输入 */
export interface CertInputs extends CamelCasedProps<ServerCert> {
    /** 附加描述信息 */
    remarks?: string;
}
/** Cdn 部署输入 */
export interface CdnDeployInputs extends CamelCasedProps<AddCdnDomainRequest> {
    /** 上一次的状态 */
    oldState?: {
        /** 输入的缓存 */
        inputCache?: string;
    };
    /** 是否异步执行（是否等待 CDN 部署完毕） */
    async?: boolean;
    /** 只刷新，不进行新的部署 */
    onlyRefresh?: boolean;
    /** 是否清除 CDN 缓存 */
    refreshCdn?: {
        /** 要清除缓存的 url (目录) 列表 */
        urls: string[];
        /**
         * 刷新类型
         * - flush：刷新产生更新的资源
         * - delete：刷新全部资源
         */
        flushType: string;
    };
    /** 是否预热 CDN */
    pushCdn?: {
        /** 要预热的 url 列表 */
        urls: string[];
        /** 预热的区域 */
        area: string;
        /** 预热时回源的 User-Agent */
        userAgent: string;
    };
}
/** Cdn 部署输出 */
export interface CdnDeployOutputs {
    /** 资源 id */
    resourceId?: string;
    /** 是否启用 https */
    https?: boolean;
    /** 域名地址 */
    domain?: string;
    /** 源地址 */
    origins?: string[];
    /** cname 字符串 */
    cname?: string;
    /** 输入的缓存 */
    inputCache?: string;
    /** 刷新成功的 url */
    refreshUrls?: string[];
}
